@@ -4,7 +4,7 @@
 #define SYSDEPS_H
 
 #undef SKALIBS_TARGET
-#define SKALIBS_TARGET "x86_64-pc-linux-gnu"
+#define SKALIBS_TARGET "x86_64-ewe-linux-musl"
 
 #undef SKALIBS_HASCLOCKRT
 #define SKALIBS_HASCLOCKRT
@@ -137,6 +137,12 @@
 #undef SKALIBS_HASPPOLL
 #define SKALIBS_HASPPOLL
 
+#undef SKALIBS_HASQSORTR_POSIX
+#define SKALIBS_HASQSORTR_POSIX
+
+#undef SKALIBS_HASQSORTR_FREEBSD
+#define SKALIBS_HASQSORTR_FREEBSD
+
 #undef SKALIBS_HASREVOKE
 
 #undef SKALIBS_HASSENDFILE
@@ -178,7 +184,6 @@
 #define SKALIBS_HASFUTIMES
 
 #undef SKALIBS_HASARC4RANDOM
-#define SKALIBS_HASARC4RANDOM
 
 #undef SKALIBS_HASARC4RANDOM_ADDRANDOM
 
@@ -189,7 +194,6 @@
 #define SKALIBS_HASNAMESPACES
 
 #undef SKALIBS_HASNSGETPARENT
-#define SKALIBS_HASNSGETPARENT
 
 #undef SKALIBS_HASEXPLICIT_BZERO
 #define SKALIBS_HASEXPLICIT_BZERO
@@ -228,6 +232,18 @@
 #undef SKALIBS_HASDLADDR
 #define SKALIBS_HASDLADDR
 
+#undef SKALIBS_HASPIDFD_OPEN
+#define SKALIBS_HASPIDFD_OPEN
+
+#undef SKALIBS_HASPRCTL
+#define SKALIBS_HASPRCTL
+
+#undef SKALIBS_HASPROCCTL
+
+#undef SKALIBS_HASKEVENT
+
+#undef SKALIBS_HASKQUEUE1
+
 #undef SKALIBS_HASDEVURANDOM
 #define SKALIBS_HASDEVURANDOM
 
